@@ -111,7 +111,7 @@ void scheme_init_char (Scheme_Startup_Env *env)
   scheme_addto_prim_instance("char?", p, env);
 
   REGISTER_SO(scheme_interned_char_p_proc);
-  p = scheme_make_folding_prim(interned_char_p, "interned-char?", 1, 1, 1);
+  p = scheme_make_folding_prim(char_p, "interned-char?", 1, 1, 1);
   SCHEME_PRIM_PROC_FLAGS(p) |= scheme_intern_prim_opt_flags(SCHEME_PRIM_IS_UNARY_INLINED
                                                             | SCHEME_PRIM_IS_OMITABLE
                                                             | SCHEME_PRIM_PRODUCES_BOOL);
@@ -260,6 +260,21 @@ Scheme_Object *scheme_make_char(mzchar ch)
   return o;
 }
 
+Scheme_Object *scheme_make_uninterned_char(mzchar ch)
+{
+  Scheme_Object *o;
+
+  if (ch < 256)
+    return scheme_char_constants[ch];
+
+  o = scheme_malloc_small_atomic_tagged(sizeof(Scheme_Small_Object));
+  CLEAR_KEY_FIELD(o);
+  o->type = scheme_char_type;
+  SCHEME_CHAR_VAL(o) = ch;
+
+  return o;
+}
+
 Scheme_Object *scheme_make_char_or_nul(mzchar v)
 {
   if ((v <= 0x10FFFF)
@@ -277,12 +292,6 @@ char_p (int argc, Scheme_Object *argv[])
   return (SCHEME_CHARP(argv[0]) ? scheme_true : scheme_false);
 }
 
-static Scheme_Object *
-interned_char_p (int argc, Scheme_Object *argv[])
-{
-  return (SCHEME_CHARP(argv[0]) && SCHEME_CHAR_VAL(argv[0]) < 256) ? scheme_true : scheme_false;
-}
-
 #define charSTD_FOLDCASE(nl) nl;
 #define charNO_FOLDCASE(nl) /* empty */
 
